//
//  ImageSwitcherViewController.m
//  ImageSwitcher
//
//  Created by Ken Anderson on 3/7/11.
//  Copyright 2011 University of Colorado, Boulder. All rights reserved.
//

#import "ImageSwitcherViewController.h"

@implementation ImageSwitcherViewController

@synthesize pages, one, two;

- (void)viewDidLoad {
    [super viewDidLoad];
	
	[one setImage:[UIImage imageNamed:@"Aragorn.jpg"]];
	current = 0;
	
	front = one;
	back  = two;
	
	[one setHidden:NO];
	[two setHidden:YES];
	
	[pages addTarget:self
		      action:@selector(pageTurning:)
	forControlEvents:UIControlEventValueChanged];
	
	UISwipeGestureRecognizer *swipeRight = [[UISwipeGestureRecognizer alloc] initWithTarget:self action:@selector(handleSwipe:)];
	UISwipeGestureRecognizer *swipeLeft  = [[UISwipeGestureRecognizer alloc] initWithTarget:self action:@selector(handleSwipe:)];
	
	[swipeRight setDirection:UISwipeGestureRecognizerDirectionRight];
	[swipeLeft setDirection:UISwipeGestureRecognizerDirectionLeft];
	
	[[self view] addGestureRecognizer:swipeRight];
	[[self view] addGestureRecognizer:swipeLeft];
	
}

- (void) handleSwipe:(UISwipeGestureRecognizer *) sender {
	UISwipeGestureRecognizerDirection direction = [sender direction];
	switch (direction) {
		case UISwipeGestureRecognizerDirectionRight:
			if ([pages currentPage] > 0) {
				[pages setCurrentPage:[pages currentPage] - 1];
				[self pageTurning:pages];
			}
			break;
		case UISwipeGestureRecognizerDirectionLeft:
			if ([pages currentPage] < 4) {
				[pages setCurrentPage:[pages currentPage] + 1];
				[self pageTurning:pages];
			}
			break;
		default:
			break;
	}
}

- (void) pageTurning: (UIPageControl *) pager {
	NSInteger nextPage = [pager currentPage];
	switch (nextPage) {
		case 0:
			[back setImage:[UIImage imageNamed:@"Aragorn.jpg"]];
			break;
		case 1:
			[back setImage:[UIImage imageNamed:@"Gollum.jpg"]];
			break;
		case 2:
			[back setImage:[UIImage imageNamed:@"Legolas.jpg"]];
			break;
		case 3:
			[back setImage:[UIImage imageNamed:@"Sauron.jpg"]];
			break;
		case 4:
			[back setImage:[UIImage imageNamed:@"theTowers.jpg"]];
			break;
		default:
			break;
	}
	
	UIViewAnimationOptions options;
	if (nextPage > current) {
		options = UIViewAnimationOptionTransitionFlipFromRight |
		          UIViewAnimationOptionShowHideTransitionViews |
		          UIViewAnimationOptionCurveEaseInOut;
	} else {
		options = UIViewAnimationOptionTransitionFlipFromLeft  |
		          UIViewAnimationOptionShowHideTransitionViews |
		          UIViewAnimationOptionCurveEaseInOut;
	}

	[UIView transitionFromView:front toView:back duration:0.5 options:options
					completion:^(BOOL finished) {
						if (finished) {
							UIImageView *temp = front;
							front = back;
							back = temp;
							current = nextPage;
						}
					}];

}

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	[pages release];
	[one release];
	[two release];
}


- (void)dealloc {
	[pages release];
	[one release];
	[two release];
    [super dealloc];
}

@end
